==> qtjambi-qt3dcore-debuginfo-macos-5.15.17.jar: sources/QtJambi3DCore/QPropertyUpdatedChangeBase_shell.cpp <==
#include "QPropertyUpdatedChangeBase_shell.h"
#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyUpdatedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyUpdatedChangeBase")
    Qt3DCore::QPropertyUpdatedChangeBase *_ptr = reinterpret_cast<Qt3DCore::QPropertyUpdatedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyUpdatedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyUpdatedChangeBase_shell) ); }

jmethodID QPropertyUpdatedChangeBase_shell::__shell_javaMethod(int pos) const { return QPropertyUpdatedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyUpdatedChangeBase), pos); }

// emitting (writeShellConstructor)
QPropertyUpdatedChangeBase_shell::QPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QPropertyUpdatedChangeBase(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChangeBase::QPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)", QPropertyUpdatedChangeBase_shell::__shell())
    QPropertyUpdatedChangeBase_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyUpdatedChangeBase));
}

// emitting (writeShellDestructor)
QPropertyUpdatedChangeBase_shell::~QPropertyUpdatedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChangeBase::~Qt3DCore::QPropertyUpdatedChangeBase()", QPropertyUpdatedChangeBase_shell::__shell())
    QPropertyUpdatedChangeBase_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyUpdatedChangeBase));
}

void QPropertyUpdatedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyUpdatedChangeBase_shell*>(ptr)->QPropertyUpdatedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyUpdatedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QPropertyUpdatedChangeBase_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QPropertyUpdatedChangeBase *__qt_this = new(__qtjambi_ptr) QPropertyUpdatedChangeBase_shell(__qt_subjectId0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPropertyUpdatedChangeBase_shell
void __qt_destruct_Qt3DCore_QPropertyUpdatedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyUpdatedChangeBase")
    reinterpret_cast<QPropertyUpdatedChangeBase_shell*>(ptr)->~QPropertyUpdatedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// Qt3DCore::QPropertyUpdatedChangeBase::QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChangeBase_initialize_1native__Lio_qt_qt3d_core_QPropertyUpdatedChangeBase_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChangeBase::QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyUpdatedChangeBase_0, sizeof(QPropertyUpdatedChangeBase_shell), typeid(Qt3DCore::QPropertyUpdatedChangeBase), true, &deleter_Qt3DCore_QPropertyUpdatedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyUpdatedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyUpdatedChangeBase>("Qt3DCore::QPropertyUpdatedChangeBase", "io/qt/qt3d/core/QPropertyUpdatedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyUpdatedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyUpdatedChangeBase_0, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyUpdatedChangeBase);
    registerSizeOfShell(typeId, sizeof(QPropertyUpdatedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QSceneChange, Qt3DCore::QPropertyUpdatedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-qt3dcore-debuginfo-macos-5.15.20.jar: sources/QtJambi3DCore/QPropertyUpdatedChangeBase_shell.cpp <==
#include "QPropertyUpdatedChangeBase_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_Qt3DCore_QPropertyUpdatedChangeBase(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for Qt3DCore::QPropertyUpdatedChangeBase")
    Qt3DCore::QPropertyUpdatedChangeBase *_ptr = reinterpret_cast<Qt3DCore::QPropertyUpdatedChangeBase *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPropertyUpdatedChangeBase_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPropertyUpdatedChangeBase_shell) ); }

jmethodID QPropertyUpdatedChangeBase_shell::__shell_javaMethod(int pos) const { return QPropertyUpdatedChangeBase_shell::__shell()->javaMethod(typeid(Qt3DCore::QPropertyUpdatedChangeBase), pos); }

// emitting (writeShellConstructor)
QPropertyUpdatedChangeBase_shell::QPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)
    : Qt3DCore::QPropertyUpdatedChangeBase(subjectId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChangeBase::QPropertyUpdatedChangeBase_shell(Qt3DCore::QNodeId subjectId0)", QPropertyUpdatedChangeBase_shell::__shell())
    QPropertyUpdatedChangeBase_shell::__shell()->constructed(typeid(Qt3DCore::QPropertyUpdatedChangeBase));
}

// emitting (writeShellDestructor)
QPropertyUpdatedChangeBase_shell::~QPropertyUpdatedChangeBase_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("Qt3DCore::QPropertyUpdatedChangeBase::~Qt3DCore::QPropertyUpdatedChangeBase()", QPropertyUpdatedChangeBase_shell::__shell())
    QPropertyUpdatedChangeBase_shell::__shell()->destructed(typeid(Qt3DCore::QPropertyUpdatedChangeBase));
}

void QPropertyUpdatedChangeBase_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPropertyUpdatedChangeBase_shell*>(ptr)->QPropertyUpdatedChangeBase_shell::__shell()->tryDeleteShell(typeid(Qt3DCore::QPropertyUpdatedChangeBase));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
void __qt_construct_Qt3DCore_QPropertyUpdatedChangeBase_Qt3DCore_QNodeId(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    jobject subjectId0 = __java_arguments[0].l;
    Qt3DCore::QNodeId __qt_subjectId0 = qtjambi_cast<Qt3DCore::QNodeId >(__jni_env, subjectId0);
    Qt3DCore::QPropertyUpdatedChangeBase *__qt_this = new(__qtjambi_ptr) QPropertyUpdatedChangeBase_shell(__qt_subjectId0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// Qt3DCore::QPropertyUpdatedChangeBase::QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qt3d_core_QPropertyUpdatedChangeBase_initialize_1native__Lio_qt_qt3d_core_QPropertyUpdatedChangeBase_2Lio_qt_qt3d_core_QNodeId_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject subjectId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("Qt3DCore::QPropertyUpdatedChangeBase::QPropertyUpdatedChangeBase(Qt3DCore::QNodeId)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = subjectId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_Qt3DCore_QPropertyUpdatedChangeBase_Qt3DCore_QNodeId, sizeof(QPropertyUpdatedChangeBase_shell), typeid(Qt3DCore::QPropertyUpdatedChangeBase), true, &deleter_Qt3DCore_QPropertyUpdatedChangeBase, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPropertyUpdatedChangeBase_shell
void __qt_destruct_Qt3DCore_QPropertyUpdatedChangeBase(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct Qt3DCore::QPropertyUpdatedChangeBase")
    reinterpret_cast<QPropertyUpdatedChangeBase_shell*>(ptr)->~QPropertyUpdatedChangeBase_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_Qt3DCore_QPropertyUpdatedChangeBase(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<Qt3DCore::QPropertyUpdatedChangeBase>("Qt3DCore::QPropertyUpdatedChangeBase", "io/qt/qt3d/core/QPropertyUpdatedChangeBase");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_Qt3DCore_QPropertyUpdatedChangeBase, {
        ConstructorInfo(&__qt_construct_Qt3DCore_QPropertyUpdatedChangeBase_Qt3DCore_QNodeId, "Lio/qt/qt3d/core/QNodeId;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_Qt3DCore_QPropertyUpdatedChangeBase);
    registerSizeOfShell(typeId, sizeof(QPropertyUpdatedChangeBase_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<Qt3DCore::QSceneChange, Qt3DCore::QPropertyUpdatedChangeBase>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
